#!/bin/bash
#Original script from Mattias Schlenker
#Modified for DSL Initrd Version by roberts 2007/07/03

. /etc/init.d/dsl-functions

# Please adjust the paths for original kernel, initrd if you are not
# booting from the normal CD ROM (e.g. Frugal install on USB)

if [ "$UID" != 0 ]; then echo "Must be root user."; exit 1; fi

CheckReturnValue() {
   case $? in
   0) ;;
   1) echo "DSL PXE Server Setup cancelled."
      exit 1
      ;;
   *) echo "An unknown error occured."
      exit 1
      ;;
   esac
}

bootfiles='/mnt/auto/cdrom/boot/isolinux'
bootfiles=$( dialog --title "DSL PXE Server Setup" --inputbox "Mount point containing DSL Initrd boot files?"  8 60 $bootfiles 3>&1 1>&2 2>&3 )
CheckReturnValue

# Try to find needed files
if [ -f $bootfiles/linux24 ]; then
   echo -n "Standby copying files for tftp server: "
   cp $bootfiles/* /opt/pxedsl/tftpboot/. 2>/dev/null &
   rotdash $!
   CheckReturnValue
   echo " Done."
else
   dialog --title "Configuration Error" --msgbox "Could not find needed boot files. You must mount the boot media device containing the initrd version of DSL." 10 60
   exit 1
fi

# Ask for Network interface:
netif=$( dialog --title "DHCP Server Setup Network interface" --inputbox "Network interface to listen on?"  8 60 eth0 3>&1 1>&2 2>&3 )
CheckReturnValue

# Try to find out IP address on that interface
ipaddr=$( ifconfig $netif | grep "inet addr:" | awk '{print $2}' | awk -F ':' '{print $2}' )
ipaddr=$( dialog --title "IP address" --inputbox "IP address of this box?"  8 60 $ipaddr 3>&1 1>&2 2>&3 )
CheckReturnValue

# Try to find out netmask
netmask=$( ifconfig $netif | grep "Mask:" | awk '{print $4}' | awk -F ':' '{print $2}' )
netmask=$( dialog --title "Netmask" --inputbox "Netmask of this box?"  8 60 $netmask 3>&1 1>&2 2>&3 )
CheckReturnValue

# Try to find nameserver
dns=$( grep nameserver /etc/resolv.conf | head -n 1 | awk '{print $2}' )
dns=$( dialog --title "Nameserver" --inputbox "Nameserver used?" 8 60 $dns 3>&1 1>&2 2>&3 )
CheckReturnValue

# Gateway to use
gateway=$( dialog --title "Gateway" --inputbox "Gateway to be used?" 8 60 $ipaddr 3>&1 1>&2 2>&3 )
CheckReturnValue

# Start of IP range
ipstart=$( dialog --title "IP range start" --inputbox "First IP address assigned by DHCP server?" 8 60  3>&1 1>&2 2>&3 )
CheckReturnValue

# End of IP range
ipend=$( dialog --title "IP range end" --inputbox "Last IP address assigned by DHCP server?" 8 60  3>&1 1>&2 2>&3 )
CheckReturnValue

# Boot file
bootfile=$( dialog --title "TFTP Boot file" --inputbox "Boot file to send to the clients? The default fits PXE clients." 10 60 "pxelinux.0" 3>&1 1>&2 2>&3 )
CheckReturnValue

# Write udhcpd.conf configuration file 
cat /opt/pxedsl/etc/udhcpd.conf.templ | \
    sed /INTERFACE/s//$netif/ | \
    sed /STARTRANGE/s//$ipstart/ | \
    sed /ENDRANGE/s//$ipend/ | \
    sed /SUBNET/s//$netmask/ | \
    sed /GATEWAY/s//$gateway/ | \
    sed /SIADDR/s//$ipaddr/ | \
    sed /NAMESERVER/s//$dns/ | \
    sed /BOOTFILE/s//$bootfile/ > /etc/udhcpd.conf

# Configuration finished

dialog --title "Configuration finished" --msgbox "Configuration finished. You might want to adjust /etc/udhcpd.conf before pressing the OK button. Now start up PXE bootable clients with at least 128MB RAM and have fun." 10 60

/opt/pxedsl/rc.d/in.tftpd.sh restart
/opt/pxedsl/rc.d/udhcpd.sh restart
